.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`Unbound <https://unbound.net/>`_ is a local DNS resolver. It supports
`DNSSEC <https://en.wikipedia.org/wiki/DNSSEC>`_ validation and can be used to
ensure that DNS queries protected by DNSSEC are signed by the correct DNS root
zone key, verified locally.
